==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ATransientModifier.h <==
// public final class soot.jimple.parser.node.ATransientModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6708161ca0b13f69 soot_jimple_parser_node_ATransientModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ATransientModifier_H_
#define _JC_soot_jimple_parser_node_ATransientModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TTransient$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$sub_refs	_jc_soot_jimple_parser_node_ATransientModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$refs	_jc_soot_jimple_parser_node_ATransientModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$nonrefs	_jc_soot_jimple_parser_node_ATransientModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$object	_jc_soot_jimple_parser_node_ATransientModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vmethods	_jc_soot_jimple_parser_node_ATransientModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vtable	_jc_soot_jimple_parser_node_ATransientModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vtype	_jc_soot_jimple_parser_node_ATransientModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$_init$b050fb848e3037c4(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ATransientModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
extern struct _jc_soot_jimple_parser_node_TTransient$object *_jc_soot_jimple_parser_node_ATransientModifier$method$getTransient$f57dfa7755654db0(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$setTransient$37c560ad15165c72(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ATransientModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$getTransient$f57dfa7755654db0;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$setTransient$37c560ad15165c72;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ATransientModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
	struct _jc_soot_jimple_parser_node_TTransient$object	*(*getTransient$f57dfa7755654db0)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setTransient$37c560ad15165c72)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ATransientModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ATransientModifier$vmethods	soot_jimple_parser_node_ATransientModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ATransientModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ATransientModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ATransientModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TTransient$object	*__5ftransient__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ATransientModifier$refs {
    _jc_soot_jimple_parser_node_ATransientModifier$sub_refs	soot_jimple_parser_node_ATransientModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ATransientModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs	soot_jimple_parser_node_ATransientModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ATransientModifier$object {
	_jc_soot_jimple_parser_node_ATransientModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ATransientModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ATransientModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ATransientModifier$vtype _jc_soot_jimple_parser_node_ATransientModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ATransientModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ATransientModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ATransientModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ATransientModifier.h <==
// public final class soot.jimple.parser.node.ATransientModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6708161ca0b13f69 soot_jimple_parser_node_ATransientModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_ATransientModifier_H_
#define _JC_soot_jimple_parser_node_ATransientModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TTransient$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$sub_refs	_jc_soot_jimple_parser_node_ATransientModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs	_jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$refs	_jc_soot_jimple_parser_node_ATransientModifier$refs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$nonrefs	_jc_soot_jimple_parser_node_ATransientModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ATransientModifier$object	_jc_soot_jimple_parser_node_ATransientModifier$object;

typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vmethods	_jc_soot_jimple_parser_node_ATransientModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vtable	_jc_soot_jimple_parser_node_ATransientModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_ATransientModifier$vtype	_jc_soot_jimple_parser_node_ATransientModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$_init$b050fb848e3037c4(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ATransientModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TTransient$object *_jc_soot_jimple_parser_node_ATransientModifier$method$getTransient$f57dfa7755654db0(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ATransientModifier$method$setTransient$37c560ad15165c72(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ATransientModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$getTransient$f57dfa7755654db0;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$setTransient$37c560ad15165c72;
extern _jc_method _jc_soot_jimple_parser_node_ATransientModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ATransientModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TTransient$object	*(*getTransient$f57dfa7755654db0)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setTransient$37c560ad15165c72)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *, struct _jc_soot_jimple_parser_node_TTransient$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ATransientModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ATransientModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_ATransientModifier$vmethods	soot_jimple_parser_node_ATransientModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_ATransientModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ATransientModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ATransientModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TTransient$object	*__5ftransient__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ATransientModifier$refs {
    _jc_soot_jimple_parser_node_ATransientModifier$sub_refs	soot_jimple_parser_node_ATransientModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ATransientModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_ATransientModifier$sub_nonrefs	soot_jimple_parser_node_ATransientModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ATransientModifier$object {
	_jc_soot_jimple_parser_node_ATransientModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ATransientModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_ATransientModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ATransientModifier$vtype _jc_soot_jimple_parser_node_ATransientModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ATransientModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ATransientModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_ATransientModifier_H_ */
